# Pylint plugin

```
pylint --load-plugins=colrev_lint --disable=all --enable=direct-status-assign colrev/
```

- [How to write a pylint plugin](https://pylint.readthedocs.io/en/latest/development_guide/how_tos/plugins.html)
- [Custom pylint checkers](https://github.com/oppia/oppia/wiki/Custom-Pylint-checks)
